import type { JSONSchema7 } from 'json-schema';
export type SchemaConversionStats = {
    propertiesCount: number;
    stringLength: number;
    enumValuesCount: number;
};
export type SchemaConversionResult = {
    schema: JSONSchema7;
    warnings: string[];
    stats: SchemaConversionStats;
};
export declare enum SchemaConversionTarget {
    OpenAI = "OPENAI",
    JSONSchema = "JSON_SCHEMA"
}
export type SchemaConversionOptions = {
    /**
     * A target flavor.
     */
    target?: SchemaConversionTarget;
    /**
     * Keys to include
     */
    propertyFilter?: (key: string) => boolean;
    /**
     * @default false
     */
    inlineDefinitions?: boolean;
    /**
     * @default 5
     */
    maxDepth?: number;
    /**
     * Allow unknown keys when processing for the JSONSchema target.
     *
     * @default false
     */
    allowUnknownKeys?: boolean;
};
export declare class SchemaConverter {
    #private;
    warnings: string[];
    stats: SchemaConversionStats;
    static convert(schema: JSONSchema7, options?: SchemaConversionOptions): SchemaConversionResult;
    protected constructor(originalSchema: JSONSchema7, options?: SchemaConversionOptions);
    private run;
    private processSchema;
    private processDefinitions;
    private countDefinitions;
    private getUsedDefinitions;
    private addDefinition;
    private addNullable;
    private processRefSchema;
    private initializeNewSchema;
    private processObjectSchema;
    private processArraySchema;
    private getUnsupportedArrayKeywords;
    private processOneOfSchema;
    private processAnyOfSchema;
    private processAllOfSchema;
    private mergeAllOfSchema;
    private processEnumSchema;
    private checkUnsupportedKeywords;
}
