import type { ErrorObject, Options, SchemaObject } from 'ajv';
import { Ajv } from 'ajv';
import type { JSONSchema7 } from 'json-schema';
export type Data = any;
export type ValidateParams = {
    ignoreMissing: boolean;
    ignoreNulls: boolean;
    errorsText: boolean;
};
export type ValidateResult = {
    valid: boolean;
    errorsText: string;
    errors: ErrorObject[];
};
export type Validator = (data: Data, options?: Partial<ValidateParams>) => ValidateResult;
export declare function parseDataPath(instancePath: string): string[];
export declare function isInvalidPropertyRequired(topLevelSchema: SchemaObject, error: ErrorObject): boolean;
export declare function refToPath(ref: string): string[];
/**
 * Given a schema object traverse it using a "instancePath" and return the schema at that path
 */
export declare function followSchemaPath(topLevelSchema: SchemaObject, instancePath: string[]): SchemaObject | undefined;
export type MinimalAjv = Pick<Ajv, 'validate' | 'errors' | 'getSchema' | 'errorsText'>;
export declare function validate(ajv: MinimalAjv, id: string, data: Data, options?: Partial<ValidateParams>): ValidateResult;
export { Ajv, type ErrorObject };
export declare function createAjv(options?: Options): Ajv;
/**
 * Apply various fixes to the schema to work around AJV issues and bugs.
 * See inline comments for more.
 */
export declare function fixSchema(schema: SchemaObject): SchemaObject;
export declare function createSchemaValidator(schema: SchemaObject | SchemaObject[], metaSchemas?: SchemaObject[], options?: Options): Validator;
/**
 * Returns a compiled validator from a schema which can act as a type guard.
 */
export declare function createTypedValidator<T>(schema: JSONSchema7, options?: Options): import("ajv").ValidateFunction<T>;
