import type { JSONSchema7, JSONSchema7Definition, JSONSchema7Type, JSONSchema7TypeName } from 'json-schema';
/**
 * Add the discriminator property to JSONSchema7, which we make frequent use of.
 */
declare module 'json-schema' {
    interface JSONSchema7 {
        discriminator?: {
            propertyName: string;
        };
    }
}
export type OneOfSchema = JSONSchema7 & {
    oneOf: Exclude<JSONSchema7['oneOf'], undefined>;
};
export type AnyOfSchema = JSONSchema7 & {
    anyOf: Exclude<JSONSchema7['anyOf'], undefined>;
};
export type AllOfSchema = JSONSchema7 & {
    allOf: Exclude<JSONSchema7['allOf'], undefined>;
};
export type ObjectSchema = JSONSchema7 & {
    type: 'object';
};
export type PropertySchema = ObjectSchema & {
    properties: Exclude<JSONSchema7['properties'], undefined>;
};
export type ArraySchema = JSONSchema7 & {
    type: 'array';
};
export type ListSchema = ArraySchema & {
    items: Exclude<JSONSchema7['items'], JSONSchema7Definition[] | undefined>;
};
export type TupleSchema = ArraySchema & {
    items: Exclude<JSONSchema7['items'], JSONSchema7Definition | undefined>;
};
export type EnumSchema = JSONSchema7 & {
    enum: Exclude<JSONSchema7['enum'], undefined>;
};
export type RefSchema = JSONSchema7 & {
    $ref: Exclude<JSONSchema7['$ref'], undefined>;
};
export type OpenAISchema = {
    type?: JSONSchema7TypeName | JSONSchema7TypeName[];
    enum?: JSONSchema7Type[];
    const?: JSONSchema7Type;
    $defs?: {
        [key: string]: OpenAISchema;
    };
    properties?: {
        [key: string]: OpenAISchema;
    };
    items?: OpenAISchema | OpenAISchema[];
    anyOf?: OpenAISchema[];
    additionalProperties?: false;
    required?: string[];
    title?: string;
    description?: string;
    $ref?: string;
};
export type OpenAIRootSchema = OpenAISchema & {
    type: 'object';
    properties: {
        [key: string]: OpenAISchema;
    };
};
